EditPrefix

Struct EditPrefix 

pub struct EditPrefix { /* private fields */ }

Implementations

Source

impl EditPrefix

pub fn new(data: &[u8]) -> Self

Creates a new EditPrefix for data, computing the checksum and length for framing it. The length of data may not be larger than u32::MAX.

Panics

Panics if data.len() > u32::MAX.

pub fn encode(&self) -> [u8; 12]

Encode this into bytes.

pub fn decode_from_slice(buf: &[u8]) -> Self

A helper function for decode, that converts the slice into a fixed length slice. The length of buf must be equal to EDIT_PREFIX_SIZE.

Panics

Panics if buf.len() != EDIT_PREFIX_SIZE.

pub fn decode(buf: &[u8; 12]) -> Self

pub const fn len(&self) -> u32

Returns the length of data this is framing.

pub fn is_valid(&self, data: &[u8]) -> bool

Checks if the data is valid, by comparing the checksum result with the stored checksum. The length of data must be equal to the stored length.

Panics

Panics if data.len() != self.len.