pub struct EditPrefix { /* private fields */ }Implementations
Sourceimpl EditPrefix
impl EditPrefix
Sourcepub fn new(data: &[u8]) -> Self
pub fn new(data: &[u8]) -> Self
Creates a new EditPrefix for data, computing the checksum and length for framing it.
The length of data may not be larger than u32::MAX.
Panics
Panics if data.len() > u32::MAX.
Sourcepub fn decode_from_slice(buf: &[u8]) -> Self
pub fn decode_from_slice(buf: &[u8]) -> Self
A helper function for decode, that converts the slice into a fixed length slice.
The length of buf must be equal to EDIT_PREFIX_SIZE.
Panics
Panics if buf.len() != EDIT_PREFIX_SIZE.
pub fn decode(buf: &[u8; 12]) -> Self